@@ -8,4 +8,8 @@ class SQLAlchemyProjectTemplate(PyramidTemplate):
 
 class MongoEngineProjectTemplate(PyramidTemplate):
     _template_dir = 'lxneng_mongoengine'
-    summary = 'Pyramid + MongoEngine + Jinja2 project using url dispatch'
\ No newline at end of file
+    summary = 'Pyramid + MongoEngine + Jinja2 project using url dispatch'
+
+class PluginProjectTemplate(PyramidTemplate):
+	_template_dir = 'lxneng_plugin'
+	summary = 'scaffold for make plugin'
\ No newline at end of file
